@@ -1,4 +1,6 @@
 package Net::Disqus::Exception;
+use strict;
+use warnings;
 use base 'Class::Accessor';
 use overload '""' => \&overload_text;
 __PACKAGE__->mk_accessors(qw(code text));
